AutoConfig class

Constructors

AutoConfig({int pMax = 3, int qMax = 3, int PMax = 1, int QMax = 1, bool useBIC = false, bool includeMean = true, bool exactMLE = true})
const

Properties

exactMLE bool
final
hashCode int
The hash code for this object.
no setterinherited
includeMean bool
final
PMax int
final
pMax int
final
QMax int
final
qMax int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useBIC bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited