ArimaOrder class

============================== Model order veri sınıfları

Constructors

ArimaOrder(int p, int d, int q)
const

Properties

d int
final
hashCode int
The hash code for this object.
no setterinherited
p int
final
q int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited