Complex class

============================== Kökler ile istikrar / terslenebilirlik

Constructors

Complex(double re, double im)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
im double
final
re double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

abs() double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator *(Complex o) Complex
operator +(Complex o) Complex
operator -(Complex o) Complex
operator /(Complex o) Complex
operator ==(Object other) bool
The equality operator.
inherited