Diagnostics class

============================== Tanı özet yapısı

Constructors

Diagnostics({required List<double> acfVals, required List<double> pacfVals, required LjungBoxResult lb, required JBResult jb, required bool arStationary, required bool maInvertible})

Properties

acfVals List<double>
final
arStationary bool
final
hashCode int
The hash code for this object.
no setterinherited
jb JBResult
final
lb LjungBoxResult
final
maInvertible bool
final
pacfVals List<double>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited