Sarima class

============================== SARIMA forecast (fit sizde varsa)

Constructors

Sarima()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

forecast(List<double> history, SarimaFit fit, int h, {double z = 1.96}) → ({List<double> lower, List<double> point, List<double> upper})