NelderMead class

Simple Nelder–Mead (parameter search)

Constructors

NelderMead({int maxIter = 1200, double alpha = 1.0, double gamma = 2.0, double rho = 0.5, double sigma = 0.5})

Properties

alpha double
final
gamma double
final
hashCode int
The hash code for this object.
no setterinherited
maxIter int
final
rho double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sigma double
final

Methods

minimize(List<double> start, double f(List<double> x)) List<double>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited