OCSBResult class

============ OCSB & Canova–Hansen (alternatives for nsdiffs) ============

Constructors

OCSBResult(double stat, int kLags)

Properties

hashCode int
The hash code for this object.
no setterinherited
kLags int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stat double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited