SarimaOrder class

Constructors

SarimaOrder(int p, int d, int q, int P, int D, int Q, int s)
const

Properties

D int
final
d int
final
hashCode int
The hash code for this object.
no setterinherited
P int
final
p int
final
Q int
final
q int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
s int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited